| Home | Libraries | People | FAQ | More

#### Examples

Construction from Specific Values Without Precision Loss
Area of Circle
Drop-in Caveats
Defining a Special Function.
Calculating a Derivative
Calculating an Integral
Polynomial Evaluation
Variable-Precision Newton Evaluation
Gauss-Laguerre quadrature

| Copyright © 2002-2020 John Maddock and Christopher Kormanyos Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)